@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2011-2019 Aurimas Cernius
+ * Copyright (C) 2011-2019,2022 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -54,20 +54,14 @@
 #endif
 
 #include <glibmm/i18n.h>
-#include <gtkmm/window.h>
-#include <gtkmm/imagemenuitem.h>
-#include <gtkmm/image.h>
-#include <gtkmm/stock.h>
 
 #include "sharp/string.hpp"
 #include "debug.hpp"
 #include "actionmanager.hpp"
-#include "iconmanager.hpp"
-#include "utils.hpp"
 
 namespace gnote {
 
-  ActionManager::ActionManager()
+  void ActionManager::init()
   {
     make_app_actions();
     make_app_menu_items();
@@ -90,8 +84,7 @@ namespace gnote {
     register_main_window_action("increase-indent", NULL, true);
     register_main_window_action("decrease-indent", NULL, true);
 
-    signal_build_main_window_search_popover.connect(sigc::mem_fun(*this, &ActionManager::add_app_menu_new_section));
-    signal_build_main_window_search_popover.connect(sigc::mem_fun(*this, &ActionManager::add_app_menu_trailing_sections));
+    signal_build_main_window_search_popover.connect(sigc::mem_fun(*this, &ActionManager::add_app_menu_items));
   }
 
 
@@ -124,29 +117,28 @@ namespace gnote {
     return action;
   }
 
-  void ActionManager::add_app_menu_item(int section, int order, const Glib::ustring & label,
-                                        const Glib::ustring & action_def)
+  void ActionManager::add_app_menu_item(int section, int order, Glib::ustring && label, Glib::ustring && action_def)
   {
-    m_app_menu_items.insert(std::make_pair(section, AppMenuItem(order, label, action_def)));
+    m_app_menu_items.insert(std::make_pair(section, AppMenuItem(order, std::move(label), std::move(action_def))));
   }
 
   void ActionManager::make_app_menu_items()
   {
-    add_app_menu_item(APP_ACTION_NEW, 100, _("_New Note"), "app.new-note");
-    add_app_menu_item(APP_ACTION_NEW, 200, _("New _Window"), "app.new-window");
-    add_app_menu_item(APP_ACTION_LAST, 50, _("_Preferences"), "app.show-preferences");
-    add_app_menu_item(APP_ACTION_LAST, 100, _("_Shortcuts"), "app.help-shortcuts");
-    add_app_menu_item(APP_ACTION_LAST, 150, _("_Help"), "app.help-contents");
-    add_app_menu_item(APP_ACTION_LAST, 200, _("_About Gnote"), "app.about");
+    add_app_menu_item(APP_SECTION_NEW, 100, _("_New Note"), "app.new-note");
+    add_app_menu_item(APP_SECTION_NEW, 200, _("New _Window"), "app.new-window");
+    add_app_menu_item(APP_SECTION_LAST, 50, _("_Preferences"), "app.show-preferences");
+    add_app_menu_item(APP_SECTION_LAST, 100, _("_Shortcuts"), "app.help-shortcuts");
+    add_app_menu_item(APP_SECTION_LAST, 150, _("_Help"), "app.help-contents");
+    add_app_menu_item(APP_SECTION_LAST, 200, _("_About Gnote"), "app.about");
   }
 
-  void ActionManager::register_main_window_action(const Glib::ustring & action, const Glib::VariantType *state_type, bool modifying)
+  void ActionManager::register_main_window_action(Glib::ustring && action, const Glib::VariantType *state_type, bool modifying)
   {
     if(m_main_window_actions.find(action) == m_main_window_actions.end()) {
-      m_main_window_actions[action] = state_type;
       if(!modifying) {
         m_non_modifying_actions.push_back(action);
       }
+      m_main_window_actions.insert(std::make_pair(std::move(action), state_type));
     }
     else {
       if(m_main_window_actions[action] != state_type) {
@@ -165,12 +157,12 @@ namespace gnote {
     return std::find(m_non_modifying_actions.begin(), m_non_modifying_actions.end(), action) == m_non_modifying_actions.end();
   }
 
-  void ActionManager::register_main_window_search_callback(const Glib::ustring & id, const Glib::ustring & action,
+  void ActionManager::register_main_window_search_callback(Glib::ustring && id, Glib::ustring && action,
                                                     sigc::slot<void, const Glib::VariantBase&> callback)
   {
     DBG_ASSERT(m_main_window_search_actions.find(id) == m_main_window_search_actions.end(), "Duplicate callback for main window search");
 
-    m_main_window_search_actions[id] = std::make_pair(action, callback);
+    m_main_window_search_actions.insert(std::make_pair(std::move(id), std::make_pair(std::move(action), callback)));
     signal_main_window_search_actions_changed();
   }
 
@@ -189,39 +181,11 @@ namespace gnote {
     return cbacks;
   }
 
-  bool ActionManager::add_app_menu_section(std::map<int, Gtk::Widget*> & widgets, int & order, int section)
+  void ActionManager::add_app_menu_items(std::vector<PopoverWidget> & widgets)
   {
-    std::pair<AppMenuItemMultiMap::const_iterator, AppMenuItemMultiMap::const_iterator>
-    range = m_app_menu_items.equal_range(section);
-
-    if(range.first != m_app_menu_items.end()) {
-      for(AppMenuItemMultiMap::const_iterator iter = range.first; iter != range.second; ++iter) {
-        widgets.insert(std::make_pair(order++, utils::create_popover_button(iter->second.action_def, iter->second.label)));
-      }
-
-      return true;
+    for(auto& iter : m_app_menu_items) {
+      widgets.push_back(PopoverWidget(iter.first, iter.second.order, utils::create_popover_button(iter.second.action_def, iter.second.label)));
     }
-
-    return false;
-  }
-
-  void ActionManager::add_app_menu_new_section(std::map<int, Gtk::Widget*> & widgets)
-  {
-    int order = 0;
-    if(add_app_menu_section(widgets, order, APP_ACTION_NEW)) {
-      // end section
-      widgets[order] = NULL;
-    }
-  }
-
-  void ActionManager::add_app_menu_trailing_sections(std::map<int, Gtk::Widget*> & widgets)
-  {
-    int order = 100000;
-    if(add_app_menu_section(widgets, order, APP_ACTION_MANAGE)) {
-      // end section
-      widgets[order++] = NULL;
-    }
-    add_app_menu_section(widgets, order, APP_ACTION_LAST);
   }
 
 }
