@@ -144,7 +144,7 @@ namespace gnote {
 
   void RemoteControl::DisplaySearchWithText(const Glib::ustring& search_text)
   {
-    MainWindow & recent_changes = m_gnote.get_main_window();
+    MainWindow & recent_changes = m_gnote.open_search_all();
     recent_changes.set_search_text(search_text);
     recent_changes.present();
     recent_changes.show_search_bar();
@@ -160,7 +160,7 @@ namespace gnote {
 
   Glib::ustring RemoteControl::FindStartHereNote()
   {
-    NoteBase::Ptr note = m_manager.find_by_uri(m_manager.start_note_uri());
+    NoteBase::Ptr note = m_manager.find_by_uri(m_gnote.preferences().start_note_uri());
     return (!note) ? "" : note->uri();
   }
 
