@@ -1,7 +1,7 @@
  /*
  * gnote
  *
- * Copyright (C) 2010-2017,2019-2021 Aurimas Cernius
+ * Copyright (C) 2010-2017,2019-2022 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -315,12 +315,7 @@ namespace gnote {
 
     if (m_window) {
       if(m_window->host()) {
-        MainWindow *win = dynamic_cast<MainWindow*>(m_window->host());
-        bool close_host = win ? win->close_on_escape() : false;
         m_window->host()->unembed_widget(*m_window);
-        if(close_host) {
-          win->close_window();
-        }
       }
       delete m_window; 
       m_window = NULL;
@@ -408,31 +403,20 @@ namespace gnote {
       m_data.data().set_cursor_position(start.get_offset());
       m_data.data().set_selection_bound_position(end.get_offset());
     }
-    else if(insert->get_name() == "insert") {
-      m_data.data().set_cursor_position(iter.get_offset());
+    else {
+      auto cursor_pos = insert_mark->get_iter().get_offset();
+      if(m_data.data().cursor_position() == cursor_pos && m_data.data().selection_bound_position() == NoteData::s_noPosition) {
+        // no change, do not queue save
+        return;
+      }
+      m_data.data().set_cursor_position(cursor_pos);
+      m_data.data().set_selection_bound_position(NoteData::s_noPosition);
     }
 
     DBG_OUT("OnBufferSetMark queueing save");
     queue_save(NO_CHANGE);
   }
 
-  void Note::on_buffer_mark_deleted(const Glib::RefPtr<Gtk::TextBuffer::Mark> & mark)
-  {
-    if(mark != get_buffer()->get_selection_bound()) {
-      return;
-    }
-
-    Gtk::TextIter start, end;
-    if(m_data.data().selection_bound_position() != m_data.data().cursor_position()
-       && !m_buffer->get_selection_bounds(start, end)) {
-      DBG_OUT("selection removed");
-      m_data.data().set_cursor_position(m_buffer->get_insert()->get_iter().get_offset());
-      m_data.data().set_selection_bound_position(NoteData::s_noPosition);
-      queue_save(NO_CHANGE);
-    }
-  }
-
-
   bool Note::on_window_destroyed(GdkEventAny * /*ev*/)
   {
     m_window = NULL;
@@ -715,8 +699,6 @@ namespace gnote {
         sigc::mem_fun(*this, &Note::on_buffer_tag_removed));
       m_mark_set_conn = m_buffer->signal_mark_set().connect(
         sigc::mem_fun(*this, &Note::on_buffer_mark_set));
-      m_mark_deleted_conn = m_buffer->signal_mark_deleted().connect(
-        sigc::mem_fun(*this, &Note::on_buffer_mark_deleted));
     }
     return m_buffer;
   }
