@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2010-2014,2017 Aurimas Cernius
+ * Copyright (C) 2010-2014,2017,2019 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -23,7 +23,6 @@
 #ifndef __NOTEBOOKS_NOTEBOOK_HPP_
 #define __NOTEBOOKS_NOTEBOOK_HPP_
 
-#include "base/macros.hpp"
 #include "tag.hpp"
 #include "note.hpp"
 
@@ -35,13 +34,13 @@ namespace notebooks {
 /// An object that represents a notebook in Tomboy
 /// </summary>
 class Notebook 
-  : public enable_shared_from_this<Notebook>
+  : public std::enable_shared_from_this<Notebook>
 {
 public:
-  typedef shared_ptr<Notebook> Ptr;
+  typedef std::shared_ptr<Notebook> Ptr;
   static const char * NOTEBOOK_TAG_PREFIX;
-  Notebook(NoteManager &, const Glib::ustring &, bool is_special = false);
-  Notebook(NoteManager &, const Tag::Ptr &);
+  Notebook(NoteManagerBase &, const Glib::ustring &, bool is_special = false);
+  Notebook(NoteManagerBase &, const Tag::Ptr &);
   Glib::ustring get_name() const
     { return m_name; }
   void set_name(const Glib::ustring &);
@@ -57,10 +56,10 @@ public:
   virtual ~Notebook()
     {}
 protected:
-  static Tag::Ptr template_tag();
-  static bool is_template_note(const Note::Ptr &);
+  Tag::Ptr template_tag() const;
+  bool is_template_note(const Note::Ptr &);
 
-  NoteManager & m_note_manager;
+  NoteManagerBase & m_note_manager;
 private:
   static Tag::Ptr s_template_tag;
 
