@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2010-2016 Aurimas Cernius
+ * Copyright (C) 2010-2016,2019 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -29,8 +29,9 @@
 #include "debug.hpp"
 #include "iactionmanager.hpp"
 #include "iconmanager.hpp"
+#include "ignote.hpp"
 #include "tag.hpp"
-#include "itagmanager.hpp"
+#include "notemanagerbase.hpp"
 #include "notewindow.hpp"
 
 
@@ -39,10 +40,10 @@ namespace notebooks {
 
   Tag::Ptr           NotebookNoteAddin::s_templateTag;
 
-  Tag::Ptr NotebookNoteAddin::get_template_tag()
+  Tag::Ptr NotebookNoteAddin::get_template_tag() const
   {
     if(!s_templateTag) {
-      s_templateTag = ITagManager::obj().get_or_create_system_tag(ITagManager::TEMPLATE_NOTE_SYSTEM_TAG);
+      s_templateTag = manager().tag_manager().get_or_create_system_tag(ITagManager::TEMPLATE_NOTE_SYSTEM_TAG);
     }
     return s_templateTag;
   }
@@ -74,7 +75,7 @@ namespace notebooks {
     auto note_win = get_window();
     note_win->signal_foregrounded.connect(sigc::mem_fun(*this, &NotebookNoteAddin::on_note_window_foregrounded));
     note_win->signal_backgrounded.connect(sigc::mem_fun(*this, &NotebookNoteAddin::on_note_window_backgrounded));
-    NotebookManager::obj().signal_notebook_list_changed
+    ignote().notebook_manager().signal_notebook_list_changed
       .connect(sigc::mem_fun(*this, &NotebookNoteAddin::on_notebooks_changed));
   }
 
@@ -84,7 +85,7 @@ namespace notebooks {
     EmbeddableWidgetHost *host = get_window()->host();
     m_new_notebook_cid = host->find_action("new-notebook")->signal_activate()
       .connect(sigc::mem_fun(*this, &NotebookNoteAddin::on_new_notebook_menu_item));
-    Notebook::Ptr current_notebook = NotebookManager::obj().get_notebook_from_note(get_note());
+    Notebook::Ptr current_notebook = ignote().notebook_manager().get_notebook_from_note(get_note());
     Glib::ustring name;
     if(current_notebook) {
       name = current_notebook->get_name();
@@ -103,16 +104,16 @@ namespace notebooks {
   }
 
 
-  std::map<int, Gtk::Widget*> NotebookNoteAddin::get_actions_popover_widgets() const
+  std::vector<gnote::PopoverWidget> NotebookNoteAddin::get_actions_popover_widgets() const
   {
     auto widgets = NoteAddin::get_actions_popover_widgets();
     if(!get_note()->contains_tag(get_template_tag())) {
       Gtk::Widget *notebook_button = utils::create_popover_submenu_button("notebooks-submenu", _("Notebook"));
-      utils::add_item_to_ordered_map(widgets, gnote::NOTEBOOK_ORDER, notebook_button);
+      widgets.push_back(gnote::PopoverWidget(gnote::NOTE_SECTION_CUSTOM_SECTIONS, gnote::NOTEBOOK_ORDER, notebook_button));
 
       auto submenu = utils::create_popover_submenu("notebooks-submenu");
       update_menu(submenu);
-      utils::add_item_to_ordered_map(widgets, 1000000, submenu);
+      widgets.push_back(gnote::PopoverWidget::create_custom_section(submenu));
     }
 
     return widgets;
@@ -123,8 +124,7 @@ namespace notebooks {
   {
     Note::List noteList;
     noteList.push_back(get_note());
-    NotebookManager::obj().prompt_create_new_notebook(
-      dynamic_cast<Gtk::Window*>(get_window()->host()), noteList);
+    NotebookManager::prompt_create_new_notebook(ignote(), dynamic_cast<Gtk::Window*>(get_window()->host()), noteList);
     get_window()->signal_popover_widgets_changed();
   }
 
@@ -135,9 +135,9 @@ namespace notebooks {
     Glib::ustring name = Glib::VariantBase::cast_dynamic<Glib::Variant<Glib::ustring>>(state).get();
     Notebook::Ptr notebook;
     if(name.size()) {
-      notebook = NotebookManager::obj().get_notebook(name);
+      notebook = ignote().notebook_manager().get_notebook(name);
     }
-    NotebookManager::obj().move_note_to_notebook(get_note(), notebook);
+    ignote().notebook_manager().move_note_to_notebook(get_note(), notebook);
   }
 
 
@@ -155,10 +155,9 @@ namespace notebooks {
     menu->add(*no_notebook_item);
 
     // Add in all the real notebooks
-    std::list<Gtk::ModelButton*> notebook_menu_items;
-    get_notebook_menu_items(notebook_menu_items);
+    auto notebook_menu_items = get_notebook_menu_items();
     if(!notebook_menu_items.empty()) {
-      FOREACH(Gtk::ModelButton *item, notebook_menu_items) {
+      for(Gtk::ModelButton *item : notebook_menu_items) {
         menu->add(*item);
       }
 
@@ -171,13 +170,12 @@ namespace notebooks {
   }
   
 
-  void NotebookNoteAddin::get_notebook_menu_items(std::list<Gtk::ModelButton*>& items) const
+  std::vector<Gtk::ModelButton*> NotebookNoteAddin::get_notebook_menu_items() const
   {
-    Glib::RefPtr<Gtk::TreeModel> model = NotebookManager::obj().get_notebooks();
+    std::vector<Gtk::ModelButton*> items;
+    Glib::RefPtr<Gtk::TreeModel> model = ignote().notebook_manager().get_notebooks();
     Gtk::TreeIter iter;
 
-    items.clear();
-
     iter = model->children().begin();
     for(iter = model->children().begin(); iter != model->children().end(); ++iter) {
       Notebook::Ptr notebook;
@@ -187,6 +185,8 @@ namespace notebooks {
       gtk_actionable_set_action_target_value(GTK_ACTIONABLE(item->gobj()), g_variant_new_string(notebook->get_name().c_str()));
       items.push_back(item);
     }
+
+    return items;
   }
 
 
