@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2010-2014,2017 Aurimas Cernius
+ * Copyright (C) 2010-2014,2017,2019 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -26,12 +26,14 @@
 
 #include <set>
 
-#include "base/macros.hpp"
 #include "notebook.hpp"
 #include "tag.hpp"
 
 
 namespace gnote {
+
+class IconManager;
+
 namespace notebooks {
 
 
@@ -39,11 +41,11 @@ class SpecialNotebook
   : public Notebook
 {
 public:
-  typedef shared_ptr<SpecialNotebook> Ptr;
+  typedef std::shared_ptr<SpecialNotebook> Ptr;
 
-  virtual Glib::RefPtr<Gdk::Pixbuf> get_icon() = 0;
+  virtual Glib::RefPtr<Gdk::Pixbuf> get_icon(IconManager & m) = 0;
 protected:
-  SpecialNotebook(NoteManager & m, const Glib::ustring &s)
+  SpecialNotebook(NoteManagerBase & m, const Glib::ustring &s)
     : Notebook(m, s, true)
     {
     }
@@ -56,12 +58,12 @@ class AllNotesNotebook
   : public SpecialNotebook
 {
 public:
-  typedef shared_ptr<AllNotesNotebook> Ptr;
-  AllNotesNotebook(NoteManager &);
+  typedef std::shared_ptr<AllNotesNotebook> Ptr;
+  AllNotesNotebook(NoteManagerBase &);
   virtual Glib::ustring get_normalized_name() const override;
   virtual bool        contains_note(const Note::Ptr & note, bool include_system = false) override;
   virtual bool        add_note(const Note::Ptr &) override;
-  virtual Glib::RefPtr<Gdk::Pixbuf> get_icon() override;
+  virtual Glib::RefPtr<Gdk::Pixbuf> get_icon(IconManager & m) override;
 };
 
 
@@ -69,12 +71,12 @@ class UnfiledNotesNotebook
   : public SpecialNotebook
 {
 public:
-  typedef shared_ptr<UnfiledNotesNotebook> Ptr;
-  UnfiledNotesNotebook(NoteManager &);
+  typedef std::shared_ptr<UnfiledNotesNotebook> Ptr;
+  UnfiledNotesNotebook(NoteManagerBase &);
   virtual Glib::ustring get_normalized_name() const override;
   virtual bool        contains_note(const Note::Ptr & note, bool include_system = false) override;
   virtual bool        add_note(const Note::Ptr &) override;
-  virtual Glib::RefPtr<Gdk::Pixbuf> get_icon() override;
+  virtual Glib::RefPtr<Gdk::Pixbuf> get_icon(IconManager & m) override;
 };
 
 
@@ -82,12 +84,12 @@ class PinnedNotesNotebook
   : public SpecialNotebook
 {
 public:
-  typedef shared_ptr<PinnedNotesNotebook> Ptr;
-  PinnedNotesNotebook(NoteManager &);
+  typedef std::shared_ptr<PinnedNotesNotebook> Ptr;
+  PinnedNotesNotebook(NoteManagerBase &);
   virtual Glib::ustring get_normalized_name() const override;
   virtual bool        contains_note(const Note::Ptr & note, bool include_system = false) override;
   virtual bool        add_note(const Note::Ptr &) override;
-  virtual Glib::RefPtr<Gdk::Pixbuf> get_icon() override;
+  virtual Glib::RefPtr<Gdk::Pixbuf> get_icon(IconManager & m) override;
 };
 
 
@@ -95,12 +97,12 @@ class ActiveNotesNotebook
   : public SpecialNotebook
 {
 public:
-  typedef shared_ptr<ActiveNotesNotebook> Ptr;
-  ActiveNotesNotebook(NoteManager &);
+  typedef std::shared_ptr<ActiveNotesNotebook> Ptr;
+  ActiveNotesNotebook(NoteManagerBase &);
   virtual Glib::ustring get_normalized_name() const override;
   virtual bool        contains_note(const Note::Ptr & note, bool include_system = false) override;
   virtual bool        add_note(const Note::Ptr &) override;
-  virtual Glib::RefPtr<Gdk::Pixbuf> get_icon() override;
+  virtual Glib::RefPtr<Gdk::Pixbuf> get_icon(IconManager & m) override;
   bool empty();
   sigc::signal<void> signal_size_changed;
 private:
