@@ -22,6 +22,7 @@
 
 #include <gtk/gtk.h>
 #include <gtkmm/image.h>
+#include <gtkmm/linkbutton.h>
 
 #include "sharp/xmlreader.hpp"
 #include "sharp/xmlwriter.hpp"
@@ -131,7 +132,7 @@ namespace gnote {
   {
     Glib::RefPtr<Gtk::TextTag> this_ref = NoteTagTable::instance()->lookup(property_name());
     start = iter;
-    if (!start.begins_tag (this_ref)) {
+    if(!start.starts_tag(this_ref)) {
       start.backward_to_tag_toggle (this_ref);
     }
     end = iter;
@@ -161,7 +162,7 @@ namespace gnote {
 
   bool NoteTag::on_event(const Glib::RefPtr<Glib::Object> & sender, GdkEvent *ev, const Gtk::TextIter & iter)
   {
-    NoteEditor::Ptr editor = NoteEditor::Ptr::cast_dynamic(sender);
+    auto editor = dynamic_cast<NoteEditor*>(sender.get());
     Gtk::TextIter start, end;
 
     if (!can_activate())
@@ -196,7 +197,7 @@ namespace gnote {
         return false;
 
       // Prevent activation when selecting links with the mouse
-      if (editor->get_buffer()->get_has_selection()) {
+      if(editor && editor->get_buffer()->get_has_selection()) {
         return false;
       }
 
@@ -210,7 +211,9 @@ namespace gnote {
       }
 
       get_extents (iter, start, end);
-      on_activate (*(editor.operator->()), start, end);
+      if(editor) {
+        on_activate(*editor, start, end);
+      }
       return false;
     }
     case GDK_KEY_PRESS:
@@ -228,7 +231,9 @@ namespace gnote {
         return false;
 
       get_extents (iter, start, end);
-      return on_activate (*(editor.operator->()), start, end);
+      if(editor) {
+        return on_activate(*editor, start, end);
+      }
     }
     default:
       break;
@@ -292,22 +297,6 @@ namespace gnote {
     }
   }
 
-  Gdk::RGBA NoteTag::get_background() const
-  {
-    /* We can't know the exact background because we're not
-       in TextView's rendering, but we can make a guess */
-    if (property_background_set().get_value())
-      return property_background_rgba().get_value();
-
-    return Gtk::TextView().get_style_context()->get_background_color();
-  }
-
-  Gdk::RGBA NoteTag::render_foreground(ContrastPaletteColor symbol)
-  {
-    return contrast_render_foreground_color(get_background(), symbol);
-  }
-
-
   void DynamicNoteTag::write(sharp::XmlWriter & xml, bool start) const
   {
     if (can_serialize()) {
@@ -379,6 +368,12 @@ namespace gnote {
   void NoteTagTable::_init_common_tags()
   {
     NoteTag::Ptr tag;
+    Gdk::RGBA active_link_color, visited_link_color;
+    {
+      Gtk::LinkButton link;
+      active_link_color = link.get_style_context()->get_color(Gtk::STATE_FLAG_LINK);
+      visited_link_color = link.get_style_context()->get_color(Gtk::STATE_FLAG_VISITED);
+    }
 
     // Font stylings
 
@@ -409,7 +404,7 @@ namespace gnote {
     add (tag);
 
     tag = NoteTag::create("note-title", 0);
-    tag->set_palette_foreground(CONTRAST_COLOR_BLUE);
+    tag->property_foreground_rgba().set_value(active_link_color);
     tag->property_scale() = Pango::SCALE_XX_LARGE;
     // FiXME: Hack around extra rewrite on open
     tag->set_can_serialize(false);
@@ -427,7 +422,7 @@ namespace gnote {
     tag = NoteTag::create("datetime", 0);
     tag->property_scale() = Pango::SCALE_SMALL;
     tag->property_style() = Pango::STYLE_ITALIC;
-    tag->set_palette_foreground(CONTRAST_COLOR_GREY);
+    tag->property_foreground_rgba().set_value(visited_link_color);
     tag->set_save_type(META);
     add (tag);
 
@@ -453,21 +448,21 @@ namespace gnote {
 
     tag = NoteTag::create("link:broken", NoteTag::CAN_ACTIVATE);
     tag->property_underline() = Pango::UNDERLINE_SINGLE;
-    tag->set_palette_foreground(CONTRAST_COLOR_GREY);
+    tag->property_foreground_rgba().set_value(visited_link_color);
     tag->set_save_type(META);
     add (tag);
     m_broken_link_tag = tag;
 
     tag = NoteTag::create("link:internal", NoteTag::CAN_ACTIVATE);
     tag->property_underline() = Pango::UNDERLINE_SINGLE;
-    tag->set_palette_foreground(CONTRAST_COLOR_BLUE);
+    tag->property_foreground_rgba().set_value(active_link_color);
     tag->set_save_type(META);
     add (tag);
     m_link_tag = tag;
 
     tag = NoteTag::create("link:url", NoteTag::CAN_ACTIVATE);
     tag->property_underline() = Pango::UNDERLINE_SINGLE;
-    tag->set_palette_foreground(CONTRAST_COLOR_BLUE);
+    tag->property_foreground_rgba().set_value(active_link_color);
     tag->set_save_type(META);
     add (tag);
     m_url_tag = tag;
