@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2011-2017,2019 Aurimas Cernius
+ * Copyright (C) 2011-2017,2019,2021 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -140,7 +140,6 @@ public:
   void set_name(const Glib::ustring & name);
   virtual void foreground() override;
   virtual void background() override;
-  virtual void hint_size(int & width, int & height) override;
   virtual void size_internals() override;
 
   virtual void perform_search(const Glib::ustring & text) override;
@@ -151,50 +150,7 @@ public:
   // use co-variant return
   virtual Gtk::Grid *embeddable_toolbar() override;
 
-  class NonModifyingNoteAction
-  {
-  public:
-    virtual ~NonModifyingNoteAction() {}
-
-    // these are required to make RefPtr
-    virtual void reference() const = 0;
-    virtual void unreference() const = 0;
-  };
-  class NonModifyingAction
-    : public Gtk::Action
-    , public NonModifyingNoteAction
-  {
-  public:
-    static Glib::RefPtr<NonModifyingAction> create()
-      {
-        return Glib::RefPtr<NonModifyingAction>(new NonModifyingAction);
-      }
-    static Glib::RefPtr<NonModifyingAction> create(const Glib::ustring & name,
-                                                   const Gtk::StockID & stock_id = Gtk::StockID(),
-                                                   const Glib::ustring & label = Glib::ustring(),
-                                                   const Glib::ustring & tooltip = Glib::ustring())
-      {
-        return Glib::RefPtr<NonModifyingAction>(new NonModifyingAction(name, stock_id, label, tooltip));
-      }
-    static Glib::RefPtr<NonModifyingAction> create(const Glib::ustring & name,
-                                                   const Glib::ustring & icon_name,
-                                                   const Glib::ustring & label = Glib::ustring(),
-                                                   const Glib::ustring & tooltip = Glib::ustring())
-      {
-        return Glib::RefPtr<NonModifyingAction>(new NonModifyingAction(name, icon_name, label, tooltip));
-      }
-    NonModifyingAction();
-    explicit NonModifyingAction(const Glib::ustring & name, const Gtk::StockID & stock_id = Gtk::StockID(),
-                                const Glib::ustring & label = Glib::ustring(),
-                                const Glib::ustring & tooltip = Glib::ustring());
-    NonModifyingAction(const Glib::ustring & name, const Glib::ustring & icon_name,
-                       const Glib::ustring & label = Glib::ustring(),
-                       const Glib::ustring & tooltip = Glib::ustring());
-    virtual void reference() const override;
-    virtual void unreference() const override;
-  };
   virtual std::vector<PopoverWidget> get_popover_widgets() override;
-  virtual std::vector<MainWindowAction::Ptr> get_widget_actions() override;
 
   void set_size(int width, int height)
     {
@@ -222,17 +178,19 @@ public:
     {
       return m_enabled;
     }
+  virtual void set_initial_focus() override;
 private:
   static Glib::RefPtr<Gio::Icon> get_icon_pin_active(IconManager & icon_manager);
   static Glib::RefPtr<Gio::Icon> get_icon_pin_down(IconManager & icon_manager);
 
   void on_delete_button_clicked(const Glib::VariantBase&);
   void on_selection_mark_set(const Gtk::TextIter&, const Glib::RefPtr<Gtk::TextMark>&);
+  void on_selection_mark_deleted(const Glib::RefPtr<Gtk::TextMark>&);
+  void on_buffer_changed();
   void on_populate_popup(Gtk::Menu*);
   Gtk::Grid *make_toolbar();
   Gtk::Grid * make_template_bar();
   void on_untemplate_button_click();
-  void on_save_size_check_button_toggled();
   void on_save_selection_check_button_toggled();
   void on_save_title_check_button_toggled();
   void on_note_tag_added(const NoteBase&, const Tag::Ptr&);
@@ -261,7 +219,6 @@ private:
   sigc::connection              m_delete_note_slot;
   sigc::connection              m_important_note_slot;
   Gtk::Grid                    *m_template_widget;
-  Gtk::CheckButton             *m_save_size_check_button;
   Gtk::CheckButton             *m_save_selection_check_button;
   Gtk::CheckButton             *m_save_title_check_button;
 
@@ -269,7 +226,6 @@ private:
   bool                         m_enabled;
 
   Tag::Ptr m_template_tag;
-  Tag::Ptr m_template_save_size_tag;
   Tag::Ptr m_template_save_selection_tag;
   Tag::Ptr m_template_save_title_tag;
 };
