@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2011,2013-2014,2017 Aurimas Cernius
+ * Copyright (C) 2011,2013-2014,2017,2019 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -27,7 +27,6 @@
 #include <memory>
 #include <vector>
 
-#include "base/macros.hpp"
 #include "note.hpp"
 #include "notebooks/notebook.hpp"
 #include "sharp/string.hpp"
@@ -40,13 +39,13 @@ class Search
 {
 public:
   typedef std::multimap<int,Note::Ptr> Results;
-  typedef shared_ptr<Results> ResultsPtr;
+  typedef std::shared_ptr<Results> ResultsPtr;
 
   template<typename T>
   static void split_watching_quotes(std::vector<T> & split,
                                     const T & source);
 
-  Search(NoteManager &);
+  Search(NoteManagerBase &);
 
     
   /// Search the notes! A match number of
@@ -77,7 +76,7 @@ public:
                                bool match_case);
 private:
 
-  NoteManager &m_manager;
+  NoteManagerBase & m_manager;
 };
 
 template<typename T>
