@@ -39,10 +39,9 @@
 namespace gnote {
 
 class SearchNotesWidget
-  : public Gtk::HPaned
+  : public Gtk::Paned
   , public EmbeddableWidget
   , public SearchableItem
-  , public HasActions
 {
 public:
   SearchNotesWidget(IGnote & g, NoteManagerBase & m);
@@ -50,12 +49,9 @@ public:
   virtual Glib::ustring get_name() const override;
   virtual void foreground() override;
   virtual void background() override;
-  virtual void hint_size(int & width, int & height) override;
   virtual void size_internals() override;
   virtual void set_initial_focus() override;
   virtual void perform_search(const Glib::ustring & search_text) override;
-  virtual std::vector<PopoverWidget> get_popover_widgets() override;
-  virtual std::vector<MainWindowAction::Ptr> get_widget_actions() override;
 
   void select_all_notes_notebook();
   void new_note();
@@ -68,7 +64,6 @@ public:
   sigc::signal<void, const Note::Ptr &> signal_open_note;
   sigc::signal<void, const Note::Ptr &> signal_open_note_new_window;
 private:
-  void make_actions();
   void perform_search();
   void restore_matches_window();
   Gtk::Widget *make_notebooks_pane();
@@ -124,13 +119,9 @@ private:
   void on_open_notebook_template_note();
   void on_new_notebook();
   void on_delete_notebook();
-  void on_settings_changed();
   void on_sorting_changed();
   void parse_sorting_setting(const Glib::ustring & sorting);
   void on_rename_notebook();
-  void callbacks_changed();
-  void register_callbacks();
-  void unregister_callbacks();
 
   class RecentSearchColumnTypes
     : public Gtk::TreeModelColumnRecord
@@ -157,12 +148,13 @@ private:
     Gtk::TreeModelColumn<Note::Ptr> note;
   };
 
-  Glib::RefPtr<Gtk::AccelGroup> m_accel_group;
-  Glib::RefPtr<Gtk::Action> m_open_note_action;
-  Glib::RefPtr<Gtk::Action> m_open_note_new_window_action;
-  Glib::RefPtr<Gtk::Action> m_delete_note_action;
-  Glib::RefPtr<Gtk::Action> m_delete_notebook_action;
-  Glib::RefPtr<Gtk::Action> m_rename_notebook_action;
+  Gtk::MenuItem *m_open_note_menu_item;
+  Gtk::MenuItem *m_open_note_new_window_menu_item;
+  Gtk::MenuItem *m_delete_note_menu_item;
+  Gtk::MenuItem *m_delete_notebook_menu_item;
+  Gtk::MenuItem *m_rename_notebook_menu_item;
+  void *m_open_note_accel;
+  void *m_open_note_new_window_accel;
   RecentSearchColumnTypes m_find_combo_columns;
   Gtk::ScrolledWindow m_matches_window;
   Gtk::Grid *m_no_matches_box;
@@ -186,8 +178,6 @@ private:
   Glib::ustring m_search_text;
   int m_sort_column_id;
   Gtk::SortType m_sort_column_order;
-  std::vector<sigc::connection> m_action_cids;
-  sigc::connection m_callback_changed_cid;
 
   static Glib::RefPtr<Gdk::Pixbuf> get_note_icon(IconManager &);
 };
