@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2010,2012-2013,2017 Aurimas Cernius
+ * Copyright (C) 2010,2012-2013,2017,2019 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  * 
  * Permission is hereby granted, free of charge, to any person obtaining a
@@ -35,9 +35,9 @@
 namespace sharp {
 
 
-  AddinsTreeModel::Ptr AddinsTreeModel::create(Gtk::TreeView * treeview)
+  AddinsTreeModel::Ptr AddinsTreeModel::create(gnote::IconManager & icon_manager, Gtk::TreeView *treeview)
   {
-    AddinsTreeModel::Ptr p(new AddinsTreeModel());
+    AddinsTreeModel::Ptr p(new AddinsTreeModel(icon_manager));
     if(treeview) {
       treeview->set_model(p);
       p->set_columns(treeview);
@@ -45,8 +45,9 @@ namespace sharp {
     return p;
   }
 
-  AddinsTreeModel::AddinsTreeModel()
+  AddinsTreeModel::AddinsTreeModel(gnote::IconManager & icon_manager)
     : Gtk::TreeStore()
+    , m_icon_manager(icon_manager)
   {
     set_column_types(m_columns);
   }
@@ -98,7 +99,7 @@ namespace sharp {
     Gtk::CellRendererPixbuf *icon_renderer = dynamic_cast<Gtk::CellRendererPixbuf*>(renderer);
     Glib::RefPtr<Gdk::Pixbuf> icon;
     if(get_module_id(iter) != "") {
-      icon = gnote::IconManager::obj().get_icon(gnote::IconManager::EMBLEM_PACKAGE, 22);
+      icon = m_icon_manager.get_icon(gnote::IconManager::EMBLEM_PACKAGE, 22);
     }
     icon_renderer->property_pixbuf() = icon;
   }
