@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2011-2012,2017,2020 Aurimas Cernius
+ * Copyright (C) 2011-2012,2017,2021 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  * 
  * Permission is hereby granted, free of charge, to any person obtaining a
@@ -62,7 +62,7 @@ namespace sharp {
     Glib::RefPtr<Gio::FileInfo> file_info = Gio::File::create_for_path(path)->query_info(
         G_FILE_ATTRIBUTE_TIME_MODIFIED + Glib::ustring(",") + G_FILE_ATTRIBUTE_TIME_MODIFIED_USEC);
     if(file_info)
-      return Glib::DateTime::create_now_local(file_info->modification_time());
+      return file_info->get_modification_date_time();
     return Glib::DateTime();
   }
 }
