@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2011,2017 Aurimas Cernius
+ * Copyright (C) 2011,2017-2019 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  * 
  * Permission is hereby granted, free of charge, to any person obtaining a
@@ -63,6 +63,13 @@ namespace sharp {
     return Glib::path_get_basename(p);
   }
 
+  Glib::ustring file_filename(const Glib::RefPtr<Gio::File> & p)
+  {
+    if(!p)
+      return "";
+    return p->get_basename();
+  }
+
   void file_delete(const Glib::ustring & p)
   {
     g_unlink(p.c_str());
@@ -117,6 +124,22 @@ namespace sharp {
     return text;
   }
 
+  Glib::ustring file_read_all_text(const Glib::RefPtr<Gio::File> & path)
+  {
+    auto stream = path->read();
+    std::ostringstream os;
+    int buf_size = 4 * 1024;
+    char buffer[buf_size];
+    gssize read = 0;
+    do {
+      read = stream->read(buffer, buf_size);
+      os.write(buffer, read);
+    }
+    while(read == buf_size);
+    stream->close();
+    return os.str();
+  }
+
   void file_write_all_text(const Glib::ustring & path, const Glib::ustring & content)
   {
     std::ofstream fout(path);
