@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2012-2014,2016,2017,2019-2020 Aurimas Cernius
+ * Copyright (C) 2012-2014,2016,2017,2019-2021 Aurimas Cernius
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -24,7 +24,6 @@
 #include <glibmm/main.h>
 #include <gtkmm/radiobutton.h>
 #include <gtkmm/scrolledwindow.h>
-#include <gtkmm/stock.h>
 #include <gtkmm/treeview.h>
 
 #include "ignote.hpp"
@@ -80,7 +79,7 @@ public:
       Gtk::Grid *hbox = manage(new Gtk::Grid);
       hbox->set_column_spacing(8);
       Gtk::Image *image = manage(new Gtk::Image);
-      image->set(Gtk::Stock::DIALOG_WARNING, Gtk::IconSize(Gtk::ICON_SIZE_DIALOG));
+      image->set_from_icon_name("dialog-warning", Gtk::IconSize(Gtk::ICON_SIZE_DIALOG));
       image->show();
       hbox->attach(*image, 0, 0, 1, 1);
 
@@ -108,7 +107,7 @@ public:
 
       hbox->show();
       outerVBox->attach(*hbox, 0, 0, 1, 1);
-      get_vbox()->pack_start(*outerVBox);
+      get_content_area()->pack_start(*outerVBox);
 
       Gtk::Grid *renameHBox = manage(new Gtk::Grid);
       renameRadio = manage(new Gtk::RadioButton(m_radio_group, _("Rename local note:")));
@@ -122,16 +121,16 @@ public:
       renameOptionsVBox->attach(*renameEntry, 0, 0, 1, 1);
       renameHBox->attach(*renameRadio, 0, 0, 1, 1);
       renameHBox->attach(*renameOptionsVBox, 1, 0, 1, 1);
-      get_vbox()->pack_start(*renameHBox);
+      get_content_area()->pack_start(*renameHBox);
 
       deleteExistingRadio = manage(new Gtk::RadioButton(m_radio_group, _("Overwrite local note")));
       deleteExistingRadio->signal_toggled().connect(sigc::mem_fun(*this, &SyncTitleConflictDialog::radio_toggled));
-      get_vbox()->pack_start(*deleteExistingRadio);
+      get_content_area()->pack_start(*deleteExistingRadio);
 
       alwaysDoThisCheck = manage(new Gtk::CheckButton(_("Always perform this action")));
-      get_vbox()->pack_start(*alwaysDoThisCheck);
+      get_content_area()->pack_start(*alwaysDoThisCheck);
 
-      continueButton = add_button(Gtk::Stock::GO_FORWARD, Gtk::RESPONSE_ACCEPT);
+      continueButton = add_button(_("_Continue"), Gtk::RESPONSE_ACCEPT);
 
       // Set initial dialog text
       header_text(_("Note conflict detected"));
@@ -237,7 +236,7 @@ SyncDialog::SyncDialog(IGnote & g, NoteManagerBase & manager)
   outerVBox->set_border_width(6);
   outerVBox->show();
   int outerVBoxRow = 0;
-  get_vbox()->pack_start(*outerVBox, true, true, 0);
+  get_content_area()->pack_start(*outerVBox, true, true, 0);
 
   // Top image and label
   Gtk::Grid *hbox = manage(new Gtk::Grid);
@@ -246,7 +245,8 @@ SyncDialog::SyncDialog(IGnote & g, NoteManagerBase & manager)
   outerVBox->attach(*hbox, 0, outerVBoxRow++, 1, 1);
 
   m_image = manage(new Gtk::Image(g.icon_manager().get_icon(IconManager::GNOTE, 48)));
-  m_image->set_alignment(0, 0);
+  m_image->set_halign(Gtk::ALIGN_START);
+  m_image->set_valign(Gtk::ALIGN_START);
   m_image->show();
   hbox->attach(*m_image, 0, 0, 1, 1);
 
@@ -259,17 +259,14 @@ SyncDialog::SyncDialog(IGnote & g, NoteManagerBase & manager)
 
   m_header_label = manage(new Gtk::Label);
   m_header_label->set_use_markup(true);
-  float xalign, yalign;
-  m_header_label->get_alignment(xalign, yalign);
-  m_header_label->set_alignment(0, yalign);
+  m_header_label->set_halign(Gtk::ALIGN_START);
   m_header_label->set_use_underline(false);
   m_header_label->set_line_wrap(true);
   m_header_label->show();
   vbox->attach(*m_header_label, 0, 0, 1, 1);
 
   m_message_label = manage(new Gtk::Label);
-  m_message_label->get_alignment(xalign, yalign);
-  m_message_label->set_alignment(0, yalign);
+  m_message_label->set_halign(Gtk::ALIGN_START);
   m_message_label->set_use_underline(false);
   m_message_label->set_line_wrap(true);
   m_message_label->set_size_request(250, -1);
@@ -284,8 +281,7 @@ SyncDialog::SyncDialog(IGnote & g, NoteManagerBase & manager)
 
   m_progress_label = manage(new Gtk::Label);
   m_progress_label->set_use_markup(true);
-  m_progress_label->get_alignment(xalign, yalign);
-  m_progress_label->set_alignment(0, yalign);
+  m_progress_label->set_halign(Gtk::ALIGN_START);
   m_progress_label->set_use_underline(false);
   m_progress_label->set_line_wrap(true);
   m_progress_label->property_wrap() = true;
@@ -342,7 +338,7 @@ SyncDialog::SyncDialog(IGnote & g, NoteManagerBase & manager)
   column->set_cell_data_func(*renderer, sigc::mem_fun(*this, &SyncDialog::treeview_col2_data_func));
 
   // Button to close dialog.
-  m_close_button = add_button(Gtk::Stock::CLOSE, static_cast<int>(Gtk::RESPONSE_CLOSE));
+  m_close_button = add_button(_("_Close"), static_cast<int>(Gtk::RESPONSE_CLOSE));
   m_close_button->set_sensitive(false);
 }
 
@@ -596,8 +592,7 @@ void SyncDialog::note_conflict_detected(const Note::Ptr & localConflictNote,
                                         NoteUpdate remoteNote,
                                         const std::vector<Glib::ustring> & noteUpdateTitles)
 {
-  int dlgBehaviorPref = m_gnote.preferences()
-    .get_schema_settings(Preferences::SCHEMA_SYNC)->get_int(Preferences::SYNC_CONFIGURED_CONFLICT_BEHAVIOR);
+  int dlgBehaviorPref = m_gnote.preferences().sync_configured_conflict_behavior();
 
   // This event handler will be called by the synchronization thread
   // so we have to use the delegate here to manipulate the GUI.
@@ -674,8 +669,7 @@ void SyncDialog::note_conflict_detected_(
     }
   }
 
-  m_gnote.preferences().get_schema_settings(Preferences::SCHEMA_SYNC)->set_int(
-    Preferences::SYNC_CONFIGURED_CONFLICT_BEHAVIOR, static_cast<int>(savedBehavior)); // TODO: Clean up
+  m_gnote.preferences().sync_configured_conflict_behavior(static_cast<int>(savedBehavior));
 
   conflictDlg.hide();
 
