@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2013-2014,2017 Aurimas Cernius
+ * Copyright (C) 2013-2014,2017,2019 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -24,13 +24,12 @@
 #ifndef __TAG_HPP_
 #define __TAG_HPP_
 
-#include <list>
 #include <map>
+#include <memory>
+#include <vector>
 
 #include <glibmm/ustring.h>
 
-#include "base/macros.hpp"
-
 namespace gnote {
 
   enum ChangeType {
@@ -45,7 +44,7 @@ namespace gnote {
   class Tag 
   {
   public:
-    typedef shared_ptr<Tag> Ptr;
+    typedef std::shared_ptr<Tag> Ptr;
     static const char * SYSTEM_TAG_PREFIX;
 
     Tag(const Glib::ustring & name);
@@ -92,7 +91,7 @@ namespace gnote {
     // Returns a list of all the notes that this tag is associated with.
     // These pointer are not meant to be freed. They are OWNED.
     // </summary>
-    void get_notes(std::list<NoteBase*> &) const;
+    std::vector<NoteBase*> get_notes() const;
     // <summary>
     // Returns the number of notes this is currently tagging.
     // </summary>
