@@ -25,16 +25,12 @@
 #endif
 
 #include <algorithm>
-
-#include <gtk/gtk.h>
+#include <condition_variable>
 
 #include <glibmm/i18n.h>
 #include <glibmm/stringutils.h>
 #include <glibmm/threads.h>
-#include <gtkmm/checkmenuitem.h>
-#include <gtkmm/icontheme.h>
 #include <gtkmm/image.h>
-#include <gtkmm/stock.h>
 #include <gtkmm/textbuffer.h>
 
 #include "sharp/xmlreader.hpp"
@@ -50,42 +46,11 @@ namespace gnote {
   namespace utils {
 
     namespace {
-      void get_menu_position (Gtk::Menu * menu,
-                              int & x,
-                              int & y,
-                              bool & push_in)
-      {
-        if (!menu->get_attach_widget() || !menu->get_attach_widget()->get_window()) {
-          // Prevent null exception in weird cases
-          x = 0;
-          y = 0;
-          push_in = true;
-          return;
-        }
-      
-        menu->get_attach_widget()->get_window()->get_origin(x, y);
-        Gdk::Rectangle rect = menu->get_attach_widget()->get_allocation();
-        x += rect.get_x();
-        y += rect.get_y();
-        
-        Gtk::Requisition menu_req, unused;
-        menu->get_preferred_size(unused, menu_req);
-        if (y + menu_req.height >= menu->get_attach_widget()->get_screen()->get_height()) {
-          y -= menu_req.height;
-        }
-        else {
-          y += rect.get_height();
-        }
-        
-        push_in = true;
-      }
-
-
       void deactivate_menu(Gtk::Menu *menu)
       {
         menu->popdown();
         if(menu->get_attach_widget()) {
-          menu->get_attach_widget()->set_state(Gtk::STATE_NORMAL);
+          menu->get_attach_widget()->set_state_flags(Gtk::STATE_FLAG_NORMAL);
         }
       }
 
@@ -101,23 +66,18 @@ namespace gnote {
 
     void popup_menu(Gtk::Menu &menu, const GdkEventButton *ev)
     {
-      guint button = 0;
-      guint32 time;
       auto event = (const GdkEvent*)ev;
-      if(event) {
-        gdk_event_get_button(event, &button);
-        time = gdk_event_get_time(event);
+      menu.signal_deactivate().connect(sigc::bind(&deactivate_menu, &menu));
+      if(!menu.get_attach_widget() || !menu.get_attach_widget()->get_window()) {
+        menu.popup_at_pointer(event);
       }
       else {
-        time = gtk_get_current_event_time();
+        int x, y;
+        menu.get_attach_widget()->get_window()->get_origin(x, y);
+        menu.popup_at_rect(menu.get_attach_widget()->get_window(), Gdk::Rectangle(x, y, 0, 0), Gdk::GRAVITY_NORTH_WEST, Gdk::GRAVITY_NORTH_WEST, event);
       }
-      menu.signal_deactivate().connect(sigc::bind(&deactivate_menu, &menu));
-      menu.popup([&menu](int & x, int & y, bool & push_in) {
-                   get_menu_position(&menu, x, y, push_in);
-                  },
-                 button, time);
       if(menu.get_attach_widget()) {
-        menu.get_attach_widget()->set_state(Gtk::STATE_SELECTED);
+        menu.get_attach_widget()->set_state_flags(Gtk::STATE_FLAG_SELECTED);
       }
     }
 
@@ -254,28 +214,26 @@ namespace gnote {
 
     void main_context_call(const sigc::slot<void> & slot)
     {
-      Glib::Threads::Mutex mutex;
-      Glib::Threads::Cond cond;
+      std::mutex mutex;
+      std::condition_variable cond;
       bool executed = false;
       std::exception_ptr ex;
 
-      mutex.lock();
+      std::unique_lock<std::mutex> lock(mutex);
       main_context_invoke([slot, &cond, &mutex, &executed, &ex]() {
+        std::unique_lock<std::mutex> lock(mutex);
         try {
-          mutex.lock();
           slot();
         }
         catch(...) {
           ex = std::current_exception();
         }
         executed = true;
-        cond.signal();
-        mutex.unlock();
+        cond.notify_one();
       });
       while(!executed) {
-        cond.wait(mutex);
+        cond.wait(lock);
       }
-      mutex.unlock();
       if(ex) {
         std::rethrow_exception(ex);
       }
@@ -327,8 +285,7 @@ namespace gnote {
       set_resizable(false);
       set_title("");
 
-      get_vbox()->set_spacing(12);
-      get_action_area()->set_layout(Gtk::BUTTONBOX_END);
+      get_content_area()->set_spacing(12);
 
       m_accel_group = Glib::RefPtr<Gtk::AccelGroup>(Gtk::AccelGroup::create());
       add_accel_group(m_accel_group);
@@ -338,24 +295,20 @@ namespace gnote {
       hbox->set_border_width(5);
       hbox->show();
       int hbox_col = 0;
-      get_vbox()->pack_start(*hbox, false, false, 0);
+      get_content_area()->pack_start(*hbox, false, false, 0);
 
       switch (msg_type) {
       case Gtk::MESSAGE_ERROR:
-        m_image = new Gtk::Image (Gtk::Stock::DIALOG_ERROR,
-                                  Gtk::ICON_SIZE_DIALOG);
+        m_image = new Gtk::Image("dialog-error", Gtk::ICON_SIZE_DIALOG);
         break;
       case Gtk::MESSAGE_QUESTION:
-        m_image = new Gtk::Image (Gtk::Stock::DIALOG_QUESTION,
-                                  Gtk::ICON_SIZE_DIALOG);
+        m_image = new Gtk::Image("dialog-question", Gtk::ICON_SIZE_DIALOG);
         break;
       case Gtk::MESSAGE_INFO:
-        m_image = new Gtk::Image (Gtk::Stock::DIALOG_INFO,
-                                  Gtk::ICON_SIZE_DIALOG);
+        m_image = new Gtk::Image("dialog-information", Gtk::ICON_SIZE_DIALOG);
         break;
       case Gtk::MESSAGE_WARNING:
-        m_image = new Gtk::Image (Gtk::Stock::DIALOG_WARNING,
-                                  Gtk::ICON_SIZE_DIALOG);
+        m_image = new Gtk::Image("dialog-warning", Gtk::ICON_SIZE_DIALOG);
         break;
       default:
         break;
@@ -364,7 +317,7 @@ namespace gnote {
       if (m_image) {
         Gtk::manage(m_image);
         m_image->show();
-        m_image->property_yalign().set_value(0);
+        m_image->set_valign(Gtk::ALIGN_START);
         hbox->attach(*m_image, hbox_col++, 0, 1, 1);
       }
 
@@ -380,7 +333,8 @@ namespace gnote {
         label->set_use_markup(true);
         label->set_justify(Gtk::JUSTIFY_LEFT);
         label->set_line_wrap(true);
-        label->set_alignment (0.0f, 0.5f);
+        label->set_halign(Gtk::ALIGN_START);
+        label->set_valign(Gtk::ALIGN_CENTER);
         label->show();
         label_vbox->attach(*label, 0, label_vbox_row++, 1, 1);
       }
@@ -390,35 +344,36 @@ namespace gnote {
         label->set_use_markup(true);
         label->set_justify(Gtk::JUSTIFY_LEFT);
         label->set_line_wrap(true);
-        label->set_alignment (0.0f, 0.5f);
+        label->set_halign(Gtk::ALIGN_START);
+        label->set_valign(Gtk::ALIGN_CENTER);
         label->show();
         label_vbox->attach(*label, 0, label_vbox_row++, 1, 1);
       }
       
       m_extra_widget_vbox = manage(new Gtk::Grid);
       m_extra_widget_vbox->show();
-      m_extra_widget_vbox->set_margin_left(12);
+      m_extra_widget_vbox->set_margin_start(12);
       label_vbox->attach(*m_extra_widget_vbox, 0, label_vbox_row++, 1, 1);
 
       switch (btn_type) {
       case Gtk::BUTTONS_NONE:
         break;
       case Gtk::BUTTONS_OK:
-        add_button (Gtk::Stock::OK, Gtk::RESPONSE_OK, true);
+        add_button(_("_OK"), Gtk::RESPONSE_OK, true);
         break;
       case Gtk::BUTTONS_CLOSE:
-        add_button (Gtk::Stock::CLOSE, Gtk::RESPONSE_CLOSE, true);
+        add_button(_("_Close"), Gtk::RESPONSE_CLOSE, true);
         break;
       case Gtk::BUTTONS_CANCEL:
-        add_button (Gtk::Stock::CANCEL, Gtk::RESPONSE_CANCEL, true);
+        add_button(_("_Cancel"), Gtk::RESPONSE_CANCEL, true);
         break;
       case Gtk::BUTTONS_YES_NO:
-        add_button (Gtk::Stock::NO, Gtk::RESPONSE_NO, false);
-        add_button (Gtk::Stock::YES, Gtk::RESPONSE_YES, true);
+        add_button(_("_No"), Gtk::RESPONSE_NO, false);
+        add_button(_("_Yes"), Gtk::RESPONSE_YES, true);
         break;
       case Gtk::BUTTONS_OK_CANCEL:
-        add_button (Gtk::Stock::CANCEL, Gtk::RESPONSE_CANCEL, false);
-        add_button (Gtk::Stock::OK, Gtk::RESPONSE_OK, true);
+        add_button(_("_Cancel"), Gtk::RESPONSE_CANCEL, false);
+        add_button(_("_OK"), Gtk::RESPONSE_OK, true);
         break;
       }
 
@@ -436,10 +391,9 @@ namespace gnote {
     }
 
 
-    void HIGMessageDialog::add_button(const Gtk::BuiltinStockID& stock_id, 
-                                       Gtk::ResponseType resp, bool is_default)
+    void HIGMessageDialog::add_button(const Glib::ustring & label, Gtk::ResponseType resp, bool is_default)
     {
-      Gtk::Button *button = manage(new Gtk::Button (stock_id));
+      Gtk::Button *button = manage(new Gtk::Button(label, true));
       button->property_can_default().set_value(true);
       
       add_button(button, resp, is_default);
@@ -690,7 +644,7 @@ namespace gnote {
         return false;
       }
 
-      if (!iter.begins_tag(m_tag)) {
+      if(!iter.starts_tag(m_tag)) {
         m_buffer->move_mark(m_mark, iter);
         return move_next();
       }
@@ -751,102 +705,5 @@ namespace gnote {
       return false;
     }
 
-    ToolMenuButton::ToolMenuButton(Gtk::Widget & widget, Gtk::Menu *menu)
-      : Gtk::ToggleToolButton(widget)
-      ,  m_menu(menu)
-    {
-      _common_init();
-    }
-
-    ToolMenuButton::ToolMenuButton(Gtk::Toolbar& toolbar, const Gtk::BuiltinStockID& stock_image, 
-                                   const Glib::ustring & label, 
-                                   Gtk::Menu * menu)
-      : Gtk::ToggleToolButton()
-      ,  m_menu(menu)
-    {
-      _common_init(*manage(new Gtk::Image(stock_image, toolbar.get_icon_size())),
-                   label);
-    }
-
-    ToolMenuButton::ToolMenuButton(Gtk::Image& image, 
-                                   const Glib::ustring & label, 
-                                   Gtk::Menu * menu)
-      : Gtk::ToggleToolButton()
-      ,  m_menu(menu)
-    {
-      _common_init(image, label);
-    }
-
-
-    void ToolMenuButton::_common_init()
-    {
-      property_can_focus() = true;
-      gtk_menu_attach_to_widget(m_menu->gobj(), static_cast<Gtk::Widget*>(this)->gobj(),
-                                NULL);
-      m_menu->signal_deactivate().connect(sigc::mem_fun(*this, &ToolMenuButton::release_button));
-      show_all();
-    }
-
-
-    void ToolMenuButton::_common_init(Gtk::Image& image, const Glib::ustring & label)
-    {
-      set_icon_widget(image);
-      set_label_widget(*manage(new Gtk::Label(label, true)));
-      _common_init();
-    }
-
-
-    bool ToolMenuButton::on_button_press_event(GdkEventButton *ev)
-    {
-      popup_menu(*m_menu, ev);
-      return true;
-    }
-
-    void ToolMenuButton::on_clicked()
-    {
-      m_menu->select_first(true);
-      popup_menu(*m_menu, NULL);
-    }
-
-    bool ToolMenuButton::on_mnemonic_activate(bool group_cycling)
-    {
-      // ToggleButton always grabs focus away from the editor,
-      // so reimplement Widget's version, which only grabs the
-      // focus if we are group cycling.
-      if (!group_cycling) {
-        activate();
-      } 
-      else if (get_can_focus()) {
-        grab_focus();
-      }
-
-      return true;
-    }
-
-
-    void ToolMenuButton::release_button()
-    {
-      set_active(false);
-    }
-
-
-    CheckAction::CheckAction(const Glib::ustring & name)
-      : Gtk::Action(name)
-      , m_checked(false)
-    {}
-
-    Gtk::Widget *CheckAction::create_menu_item_vfunc()
-    {
-      Gtk::CheckMenuItem *item = new Gtk::CheckMenuItem;
-      item->set_active(m_checked);
-      return item;
-    }
-
-    void CheckAction::on_activate()
-    {
-      m_checked = !m_checked;
-      Gtk::Action::on_activate();
-    }
-
   }
 }
